function I = Input

I.Nspace = 32;      %Number of discrete points

% input parameters for main function
I.deltat = 0.2*1e-3;%Time step (first part in ms)
I.tend = 1000;       % Total time steps for simulation.
I.RK = 2;           % Runge Kutta Integration, 2 = RK2 ; 4 = RK4
I.FUN = 'first_order_derivative';   % name of the function with 1st order derivative eqns for variables.

% input parameters for Liley's model
I.del_Vrest = -1.8;    	% effect of altering extrasynaptic ion channels. (unit: mV)
I.lambda_Ach = 1.25;	% effect of muscarinic neuromodulation
I.lambda_i = 1;       	%An INITIAL value of lambda_i - WILL GET OVERWRITTEN later. Lets us find stationary states.
I.gamma_i = 65;        	% inhibitory synaptic rate constant.
I.gamma_e = 300;       	% excitatory synaptic rate constant.
I.lamda_ee = 0.20;      % characteristic inverse length-scale for connections. Lambda in mm-1 - scaled by scaleL *************Was 0.04 mm-1
I.nu = 1;              	%How much noise simulation do we do. 1 = pure poisson sc terms, 0 = pure eqm subcortical terms.
I.v = 1400;            	% mean axonal conduction speed.
I.q = 0;              	%mtw 21 november 2006. Do q=0 initially. Then try other values.

% input parameters for find_initial_states function
I.branch = 1;       %for selecting starting point from:   0 = Bottom branch  or   1 = Upper Branch
I.graphFlag = 0;    % plot graphs of steady-state error residuals. 1 = enable graph plotting    ;   0 = disable graph plotting

% input parameters for find_trajec function
I.trajectory = 0;   %Flag for trajectory - do we have a drug trajectory (1) a user-path (2) or no path (0)

% input parameters for noise function
I.poissflag = 0;   	%do we want the poisson noise? THINK CAREFULLY. 1=poisson, 0=gaussian imitation

% input parameters for perturbation function
I.kicker = 0;  	% Perturbation flag:    choose true to activate perturbation or false to deactivate
I.kick_division_period = 1; % division period for perturbation
I.kickTime = 0.1;   % time duration of kicking
I.kickVoltage = 10; % Apply 10mV kick
I.x_area = 16;%12:13;   % area for applying kick
I.y_area = 16;%16:17;

% input parameters for grapg_output function
I.t_step_4_tplot = 10;      % user defined No. of t steps for tplot increment
I.t_step_4_graph = 100;     % user defined No. of t steps for plot (No graph will be generated if set to 0, for faster simulation)
I.plotted_variable = 1;     % user defined varaible for plot (1 is Ve)
I.saved_variable = 1;     % user defined varaible to be saved (1 is Ve, [2 4 6] means Vi, PHI_ei & PHI_ii are going to be saved, and ':' means all variables will be saved)
I.x_axis_range = [1 I.Nspace];
I.y_axis_range = [1 I.Nspace];
I.z_axis_range = [-70 -35];
I.xtick = [0, 0.25, 0.5 0.75, 1.0]*I.Nspace;
I.ytick = [0, 0.25, 0.5 0.75, 1.0]*I.Nspace;
I.x_axis_label = 'number';
I.y_axis_label = '';
I.z_axis_label = 'Ve /mV';

% input parameters for save_output function
I.dataFlag = 0;         % true (or 1) = enable data saving ;   false (or 0) = disable
I.stabilityFlag = 0;	% true (or 1) = do stability test  ;   false (or 0) = ignore stability test
I.movieFlag = 0;        % true (or 1) = saving the movie   ;   false (or 0) = don't save the movie
I.DataFileName = 'firing_rates_etc';    % file name for the data output
I.MovieFileName = 'movie_temp';         % file name for the movie output

% the following empty are created for data saving, do NOT delete or modify
global O
O.Equilibrium = [];             % empty array for stationary states results
O.eigenvalues_14x14 = [];       % empty array for eigenvalues results
O.largest_eigenvalue_14x14 = [];% empty array for largest eigenvalues results
O.oscillation_freq_14x14 = [];  % empty array for oscillation frequency results

%**************************************************************************
% user input parameters for both function power_spectrum and function
% variable_analysis
I.Analyzed_Variable = 1;
I.settling_time = 5;    % the data within the settling time will be ignored for processing (unit in second)

% user input parameters for processing power spectrum (function
% Power_Specturm)
I.division_period = 2.5;% user-defined value for fourier transform time interval (unit in second)

% user input parameters for plotting soma potential (function Ve_analysis)
I.user_defined_point_x = 8;
I.user_defined_point_y = 16;

%**************************************************************************
% DO NOT modify the parameters below unless necessary...
I.lcortex = 0.5*1e3;% Cortex is 50 cm in size. We use mm in calculation 
I.deltax = I.lcortex/I.Nspace;          % Step size
areapermac = 1^2;   %Area per macrocolumn in mm2. NOTE UNITS Usually 1^2 mm2
I.macsperbrain = I.lcortex^2 / areapermac;  %Number of macrocolumns in our simulation
I.del_Vrest_mat = I.del_Vrest*(zeros(I.Nspace,I.Nspace)+1);  %Delta V rest in matrix form
I.Nsearch = 20000;
I.gamma_inhib_standard = I.gamma_i;     %The standard value of gamma_i which the drug application scales
I.lambda_inhib_standard = I.lambda_i;	%The standard value of lambda_i which the drug scales.

return