function Power_Specturm
%
% Jay Chang 4 October 2006. Code for calculating power spectrum
%
% Marcus Wilson comments 5 october 2006. Still need to put into epochs
% (discard first?)
% Calculate Nyqvist frequency and use this to cut-off xaxis.

clear all;

testing_mode = 0;   % 1, 2 or 3 are testing mode, 0 is normal mode.

%**************************************************************************
% The section below is the testing cases for power spectrum

if testing_mode ~= 0
    warning('testing mode activated!!! (function Power_Specturm)');
    fprintf('\n press any key to proceed testing or Ctrl-C to stop the program \n\n\n');
    pause
    % uses these values for the parameters below for the testing cases.
    Nspace = 32;
    deltat = 0.2*1e-3;
    lcortex = 0.5*1e3;
    deltax = lcortex/Nspace;
    t_step_4_tplot = 10;
    tend = 10000;
    
    t_increment = deltat * t_step_4_tplot;
    T = tend*deltat;
    
    testing_time = 0:t_increment:T;
    settling_time = 0.2;
    division_period = 0.5;

switch testing_mode
    
    case 1
        % This case gives a sine wave signal with constant frequency.
        testing_frequency = 20; % unit in Hz
        xy = 10*sin(2*pi*testing_frequency*testing_time);
        for i = 1:length(testing_time)
            svec(1:Nspace,1:Nspace,1,i) = xy(i);
        end

    case 2
        % This case gives a signal with frequency proportional to the time
        
        % frequency ranges from 1 - 10 Hz
        testing_frequency = linspace(1,10,length(testing_time));
        
        % frequency is proportional to the time in this case
        y = sin(2*pi*testing_frequency.*testing_time);
        for i = 1:length(testing_time)
            svec(:,:,1,i) = peaks(32) * y(i) -65;
        end

    case 3
        % This case gives a signal with frequency proprtional to the time, and also
        % has ripple in space.
        
        % frequency ranges from 1 - 10 Hz
        testing_frequency = linspace(1,10,length(testing_time));
        
        % frequency is proportional to the time in this case
        y = sin(2*pi*testing_frequency.*testing_time);
        for i = 1:length(testing_time)
            if (i < 200) && (i >= 0)
                testing_space = zeros(32,32);
                testing_space(1:5,1:5) = 10;
            elseif (i < 400) && (i >= 200)
                testing_space = zeros(32,32);
                testing_space(6:10,6:10) = 10;
            elseif (i < 600) && (i >= 400)
                testing_space = zeros(32,32);
                testing_space(11:15,11:15) = 10;
            elseif (i < 800) && (i >= 600)
                testing_space = zeros(32,32);
                testing_space(16:20,16:20) = 10;
            else
                testing_space = zeros(32,32);
                testing_space(21:25,21:25) = 10;
            end
            svec(:,:,1,i) = testing_space * y(i) -65;
        end

    otherwise
        error('Unknown Power Spectrum testing case!');
end
%**************************************************************************
% read in the data simulated by function Cortex_System
else
        global I;
        I = Input;              % Set the global parameters for inputs
        load(I.DataFileName);               % load data from Cortex_System
        
        % the data within the settling time will be ignored for processing
        % (unit in second)
        settling_time = I.settling_time;
        
        % user-defined value for fourier transform time interval (unit in
        % second)
        division_period = I.division_period;
        Variable = I.Analyzed_Variable;
end

% time between each RECORDED datapoint
t_increment = deltat * t_step_4_tplot;  

% *************************************************************************
% the codes here read-in the data after the settling time(wait for signal
% to settle)

% convert settling_time from seconds to No. of time elements in the vector
settling_time = settling_time / t_increment;
if settling_time > length(svec(1,1,1,:))
    error('settling time is longer than the data time length, please inputs a smaller value for settling time');
else
    V(:,:,:) = svec(:,:,Variable,(settling_time:end));% read in the variable
end
% *************************************************************************

% convert division time interval in seconds to No. of elements
division_size = division_period / t_increment;

% the total No. of time elements in the data
total_time_steps = length(V(1,1,:));

% *************************************************************************
% the if statement below is for preventing error occur if user inputs a
% division period larger than the total time of the data.
if division_size > total_time_steps
    division_size = total_time_steps;
    % if user input a division period larger than the total time of the
    % data, then the division period will be changed to be the same length
    % as the total time of the data.
end
% *************************************************************************

total_divisions = floor(total_time_steps / division_size);  
% only do the fourier transform for the division with full period time
% length. (ignore the numbers of data in the end if they are not enough to
% complete a full division.)

nyquist_time = 1/(2*t_increment);	% Nyquist angular frequency for time
nyquist_space = 2*pi/(2*deltax);	% Nyquist wavevector for space

for division = 1:total_divisions

V_division(:,:,:) = ...
    V(:,:,((((division-1)*division_size)+1):(division*division_size)));
% read-in the data for the division to do the fourier transform.

% fourier transform of temporal component
i = 1;
for x = 1:Nspace
    for y = 1:Nspace
        Vt(1,:) = V_division(x,y,:);           % Ve discrete
        Vk = fft(Vt);                           % fourier transform
        Vk_square = Vk .* conj(Vk);             % Power, |Vk|^2
        scale_factor = (t_increment/(2*pi))*sum(Vt.^2) / sum(Vk_square);
        P_temporal(i,:) = Vk_square * scale_factor; % corrected Power
        i = i+1;
    end
end

Power_temporal(division,:) = mean(P_temporal);	% average Power

%remove constant term so we can see the rest
Power_temporal(division,1) = NaN;

frequency(1:length(Power_temporal(division,:))) = ...
    ((1:length(Power_temporal(division,:)))-1)/division_period;
% calculates the frequency vector. (divide by the division period time)

figure(1); clf;
subplot(121)
plot(frequency,Power_temporal(division,:), 'linewidth', 2)
xlabel('Frequency (Hz)', 'fontsize', 16)
ylabel('Power fluctuation, |V_k|^2  (mV^2 / (Hz) ) ', 'fontsize', 16)
title(['Power Spectrum, division = ', num2str(division)], 'fontsize', 18)
set(gca,'xlim',[0 nyquist_time])
set(gca,'xtick',[0 0.2 0.4 0.6 0.8 1]*nyquist_time)  % more meaningful axis

%**************************************************************************
% Now we do the fourier transform of spatial components
i = 1;
% The for loop here does fourier transform through x-axis
for x = 1:Nspace
    V_ij(:,:) = V_division(x,:,:);         % V_ij here = Ve(y,t)
    V_qxqy = fft2(V_ij);                    % do the 2-D fourier transform
    V_qxqy_square = V_qxqy .* conj(V_qxqy);	%Power
    scale_factor = (deltax*t_increment / (4*pi^2) )*sum(sum(V_ij.^2)) / ...
        sum(sum(V_qxqy_square));
    P_spatial(i,:,:) = V_qxqy_square * scale_factor;
    i = i+1;
end

% The for loop here does fourier transform through y-axis
for y = 1:Nspace
    V_ij(:,:) = V_division(:,y,:);         % V_ij here = Ve(x,t)
    V_qxqy = fft2(V_ij);                    % do the 2-D fourier transform
    V_qxqy_square = V_qxqy .* conj(V_qxqy);	%Power
    scale_factor = (deltax*t_increment / (4*pi^2) )*sum(sum(V_ij.^2)) / ...
        sum(sum(V_qxqy_square));
    P_spatial(i,:,:) = V_qxqy_square * scale_factor;
    i = i+1;
end

Power_spatial(:,:) = mean(P_spatial);       % average Power
Power_spatial(1,:) = NaN; 	%remove constant term so we can see the rest

% calculates the spatial frequency
q(1:Nspace) = 2*pi*((1:Nspace)-1)/lcortex;

% creates q matrix for scaling power
q_matrix = q'*ones(1,length(Power_spatial(1,:)));

Power_spatial = Power_spatial ./ q_matrix;	% scaling power

% saves power data for averaging later on
Power_spatial_2(division,:,:) = Power_spatial(:,:);

subplot(122)
mesh(frequency,q,Power_spatial)
xlabel('Frequency (Hz)', 'fontsize', 16)
ylabel('q (mm^{-1})', 'fontsize', 16)
zlabel('Power fluctuation (mV^2 / (Hz) / (mm^{-1})', 'fontsize', 16)
title(['Power Spectrum, division = ', num2str(division)], 'fontsize', 18)
set(gca,'xlim',[0 nyquist_time])
set(gca,'ylim', [0 nyquist_space])

pause
end

% plot out the power spectrum if there are more than one division.
if division > 1
    Power_temporal_2 = mean(Power_temporal);
division = (1:total_divisions); % gets the vector for division
Power_temporal = Power_temporal';
figure(1); clf; colormap(jet)
%subplot(221)
%mesh(division,frequency,Power_temporal)
surf(division,frequency,Power_temporal)
set(gca,'xlim',[division(1) division(end)]);
set(gca,'ylim',[frequency(2) nyquist_time]);
xlabel('Division', 'fontsize', 16)
ylabel('Frequency (Hz)', 'fontsize', 16)
title('Power Spectrum', 'fontsize', 18)
view(0,90);

%subplot(222)
%plot(frequency,Power_temporal_2, 'linewidth', 2)
%xlabel('Frequency (Hz)', 'fontsize', 16)
%ylabel('Power fluctuation, |V_k|^2  (mV^2 / (Hz) ) ', 'fontsize', 16)
%title('Average Power Spectrum', 'fontsize', 18)
%set(gca,'xlim',[0 nyquist_time])
%set(gca,'xtick',[0 0.2 0.4 0.6 0.8 1]*nyquist_time)

%Power_spatial_3(:,:) = mean(Power_spatial_2);
%subplot(223)
%mesh(frequency,q,Power_spatial_3)
%xlabel('Frequency (Hz)', 'fontsize', 16)
%ylabel('q (mm^{-1})', 'fontsize', 16)
%zlabel('Power fluctuation (mV^2 / (Hz) / (mm^{-1})', 'fontsize', 16)
%title('Average Power Spectrum', 'fontsize', 18)
%set(gca,'xlim',[0 nyquist_time])
%set(gca,'ylim', [0 nyquist_space])
end

return