function f_out = Runge_Kutta_Integration(FUN, time, f, deltat, RK)
% This function does Runge Kutta Integration for the variables. User can
% choose either RK2 or RK4 method for integration.
switch RK
    case 2
        K1 = feval(FUN, time, f, deltat);
        K2 = feval(FUN, (time + deltat), (f + deltat*K1), deltat);
        f_out = f + deltat*(K1 + K2)/2;
    case 4
        K1 = feval(FUN, time, f, deltat);
        K2 = feval(FUN, (time + 0.5*deltat), (f + 0.5*deltat*K1), deltat);
        K3 = feval(FUN, (time + 0.5*deltat), (f + 0.5*deltat*K2), deltat);
        K4 = feval(FUN, (time + deltat), (f + deltat*K3), deltat);
        f_out = f + deltat*(K1 + 2*K2 + 2*K3 + K4)/6;
    otherwise
        warning('Unknown Numerical Integration method!');
        error('Only "2" or "4" are acceptable for "RK" input');
end
return