function [eigenvalues, largest_eigenvalue, oscillation_freq] ...
    = Steady_States_stability_14x14(equilibrium)

%**************************************************************************
% This section is the code of testing mode.
global O
if O.stability_testing_mode ~= 0
    % calls the testing parameters
    [del_Vrest lambda_Ach lambda_i v gamma_ee gamma_ii lamda_ee q] = ...
        deal(O.del_Vrest, O.lambda_Ach, O.lambda_i, O.v, O.gamma_ee, ...
        O.gamma_ii, O.lamda_ee, O.q);
    fprintf('\n testing mode activated (Steady_States_stability_14x14) \n\n\n');
else
%**************************************************************************
    global I;
    [del_Vrest lambda_Ach lambda_i v gamma_ee gamma_ii lamda_ee q] = ...
        deal(I.del_Vrest, I.lambda_Ach, I.lambda_i, I.v, I.gamma_e, ...
        I.gamma_i, I.lamda_ee, I.q);
end

[Ve Vi PHI_ee Xee PHI_ei Xei PHI_ie Xie PHI_ii Xii phi_ee Yee phi_ei Yei] ...
    = deal(equilibrium(1), equilibrium(2), equilibrium(3), equilibrium(4), ...
    equilibrium(5), equilibrium(6), equilibrium(7), equilibrium(8), ...
    equilibrium(9), equilibrium(10), equilibrium(11), equilibrium(12), ...
    equilibrium(13), equilibrium(14));

global H;
[Ve_rev Vi_rev Ve_rest Vi_rest rho_i rho_e ...
    N_ee_a N_ei_a N_ee_b N_ei_b N_ie_b N_ii_b] = deal(...
    H.Ve_rev, H.Vi_rev, H.Ve_rest, H.Vi_rest, H.gi, H.ge, ...
    H.Nee_a, H.Nei_a, H.Nee_b, H.Nei_b, H.Nie_b, H.Nii_b);

gamma_ei = gamma_ee;
gamma_ie = gamma_ii;
lamda_ei = lamda_ee;

tau_e = H.tau_e * 0.001;	%Puts tau_e in seconds
tau_i = H.tau_i * 0.001;	%Puts tau_i in seconds
     
%Calculate the derivatives - use vector form
psi_ee = Psi_ee(Ve);
psi_ei = Psi_ei(Vi);
psi_ie = Psi_ie(Ve);
psi_ii = Psi_ii(Vi);

% creates a 14x14 matrix for Jacobian and initializes it with zeros
J = zeros(14,14);

% Eqns & Variables sequence for the Jacobian matrix:
% 1:Ve, 2:Vi, 3:PHI_ee, 4:Xee, 5:PHI_ei, 6:Xei, 7:PHI_ie, 8:Xie, 9:PHI_ii,
% 10:Xii, 11:phi_ee, 12:ZYee, 13:phi_ei, 14:Yei

% partial derivatives from Eqs. (A1)
%mtw 21 november 2006 correction. 1/tau_e not tau_e
ddVe_dVe = (1/tau_e)*(-1 - rho_e*lambda_Ach*PHI_ee/(Ve_rev-Ve_rest) - ...
    rho_i*lambda_i*PHI_ie/(Vi_rev-Ve_rest));
ddVe_dPHI_ee = (1/tau_e)*(rho_e*lambda_Ach*psi_ee);
ddVe_dPHI_ie = (1/tau_e)*(rho_i*lambda_i*psi_ie);
J(1,1) = ddVe_dVe;      % puts to Jacobian matrix
J(1,3) = ddVe_dPHI_ee;
J(1,7) = ddVe_dPHI_ie;

% partial derivatives from Eqs. (A2)
%mtw 21 november 2006. Correction. 1/tau_i not tau_i
ddVi_dVi = (1/tau_i)*(-1 - rho_e*lambda_Ach*PHI_ei/(Ve_rev-Vi_rest) - ...
    rho_i*lambda_i*PHI_ii/(Vi_rev-Vi_rest));
ddVi_dPHI_ei = (1/tau_i)*(rho_e*lambda_Ach*psi_ei);
ddVi_dPHI_ii = (1/tau_i)*(rho_i*lambda_i*psi_ii);
J(2,2) = ddVi_dVi;
J(2,5) = ddVi_dPHI_ei;
J(2,9) = ddVi_dPHI_ii;

% partial derivatives from Eqs. (A3)
ddPHI_ee_dXee = 1;
ddXee_dXee = -2 * gamma_ee;
ddXee_dPHI_ee = - gamma_ee^2;
ddXee_dphi_ee = gamma_ee^2 * N_ee_a;
ddXee_dVe = gamma_ee^2 * N_ee_b * d_Qsige(Ve);
J(3,4) = ddPHI_ee_dXee;
J(4,4) = ddXee_dXee;
J(4,3) = ddXee_dPHI_ee;
J(4,11) = ddXee_dphi_ee;
J(4,1) = ddXee_dVe;

% partial derivatives from Eqs. (A4)
ddPHI_ei_dXei = 1;
ddXei_dXei = -2 * gamma_ei;
ddXei_dPHI_ei = - gamma_ei^2;
ddXei_dphi_ei = gamma_ei^2 * N_ei_a;
ddXei_dVe = gamma_ei^2 * N_ei_b * d_Qsige(Ve);
J(5,6) = ddPHI_ei_dXei;
J(6,6) = ddXei_dXei;
J(6,5) = ddXei_dPHI_ei;
J(6,13) = ddXei_dphi_ei;
J(6,1) = ddXei_dVe;

% partial derivatives from Eqs. (A5)
ddPHI_ie_dXie = 1;
ddXie_dXie = -2 * gamma_ie;
ddXie_dPHI_ie = - gamma_ie^2;
ddXie_dVi = gamma_ie^2 * N_ie_b * d_Qsigi(Vi);
J(7,8) = ddPHI_ie_dXie;
J(8,8) = ddXie_dXie;
J(8,7) = ddXie_dPHI_ie;
J(8,2) = ddXie_dVi;

% partial derivatives from Eqs. (A6)
ddPHI_ii_dXii = 1;
ddXii_dXii = -2 * gamma_ii;
ddXii_dPHI_ii = - gamma_ii^2;
ddXii_dVi = gamma_ii^2 * N_ii_b * d_Qsigi(Vi);
J(9,10) = ddPHI_ii_dXii;
J(10,10) = ddXii_dXii;
J(10,9) = ddXii_dPHI_ii;
J(10,2) = ddXii_dVi;

% partial derivatives from Eqs. (A7)
ddphi_ee_dYee = 1;
ddYee_dYee = -2*v*lamda_ee;
ddYee_dphi_ee = -v^2*lamda_ee^2 - v^2*q^2;
ddYee_dVe = v^2*lamda_ee^2*d_Qsige(Ve);
J(11,12) = ddphi_ee_dYee;
J(12,12) = ddYee_dYee;
J(12,11) = ddYee_dphi_ee;
J(12,1) = ddYee_dVe;

% partial derivatives from Eqs. (A8)
ddphi_ei_dYei = 1;
ddYei_dYei = -2*v*lamda_ei;
ddYei_dphi_ei = -v^2*lamda_ei^2 - v^2*q^2;
ddYei_dVe = v^2*lamda_ei^2*d_Qsige(Ve);
J(13,14) = ddphi_ei_dYei;
J(14,14) = ddYei_dYei;
J(14,13) = ddYei_dphi_ei;
J(14,1) = ddYei_dVe;

eigenvalues = eig(J);      % evaluates the eigenvalues
[largest_eigenvalue, index] = max(real(eigenvalues));
largest_eigenvalue = eigenvalues(index);    % derive the largest eigenvalue
% finds the oscillation frequency (unit in Hz)
oscillation_freq = imag(largest_eigenvalue) / (2*pi);

return