function Variable_Variation
% This function plots the time variation of a user-selected variable.
clear all;

global I;
I = Input;              % Set the global parameters for inputs

load(I.DataFileName);      % load data from Cortex_System
t_increment = deltat * t_step_4_tplot;%time between each RECORDED datapoint

[user_defined_point_x user_defined_point_y Analyzed_Variable] = deal(...
    I.user_defined_point_x, I.user_defined_point_y, I.Analyzed_Variable);

% the data within the settling time will be ignored for processing (unit in
% second)
settling_time = I.settling_time;

% convert settling_time from seconds to No. of time elements in the vector
settling_time = settling_time / t_increment;
if settling_time > length(svec(1,1,1,:))
    error('settling time is longer than the data time length, please inputs a smaller value for settling time');
else
    % read in Ve with user-defined y-axis
    Variable_y(:,:) = svec(:, user_defined_point_y, Analyzed_Variable, ...
        (settling_time:end));
    
    % read in Ve with a user-defined point
    Variable_xy(1,:) = svec(user_defined_point_x, user_defined_point_y, ...
        Analyzed_Variable, (settling_time:end));
end

space = (1:Nspace)*deltax/1000; % calculates the space vector
time = (1:length(Variable_y(1,:)))*t_increment;% calculates the time vector


figure(1); clf;

subplot(121)
plot(time,Variable_xy)
set(gca,'xlim',[0 time(end)]);
xlabel('time (s)', 'fontsize', 16)
ylabel('Ve(t) (mV)', 'fontsize', 16)
title('excitatory soma voltage vs. time', 'fontsize', 18)

subplot(122)
mesh(time,space,Variable_y)
set(gca,'xlim',[0 time(end)]);
set(gca,'ylim',[space(1) space(end)]);
xlabel('time (s)', 'fontsize', 16)
ylabel('space(y-axis) (m)', 'fontsize', 16)
title('excitatory soma voltage vs. time & space(y-axis)', 'fontsize', 18)
colormap(gray);
caxis([-65 -50]);
view(0,90);
return