function f = find_steady_states
% This function finds the initial condition for the variables
global H;

%**************************************************************************
% This section is the code of testing mode.

global O
O.stability_testing_mode = 0;   % 1, 2 or 3 are testing mode, 0 is normal mode.
if O.stability_testing_mode ~= 0
    warning('testing mode activated!!! (function find_steady_states)');
    fprintf('\n press any key to proceed testing or Ctrl-C to stop the program \n\n\n');
    pause
    % testing parameters are for changing here.
    switch O.stability_testing_mode
        case 1
            [O.del_Vrest O.lambda_Ach] = deal(-1.8, 1.15)
            fprintf('\n This should result three unstable states \n\n\n');
        case 2
            [O.del_Vrest O.lambda_Ach] = deal(10, 0.20)   % all stable
            fprintf('\n This should result all stable \n\n\n');
        case 3
            [O.del_Vrest O.lambda_Ach] = deal(10, 0.21)   % 1 unstable
            fprintf('\n This should result one unstable state \n\n\n');
        otherwise
            error('Unknown 14x14 Stability testing case!');
    end
    O.lambda_i = 1;
    O.gamma_ee = 1342;
    O.gamma_ii = 14.53;
    [O.v O.lamda_ee O.q O.N_ei_a_boost] = deal(1400, 0.20, 0, 1);
    
    [del_Vrest lambda_Ach lambda_i] = ...
        deal(O.del_Vrest, O.lambda_Ach, O.lambda_i);
    [graphFlag Nsearch branch Nspace] = ...
        deal(1, 20000, 0, 32);
    
    H=init_hasselmo_globs;	% Set the global parameters for constants
else
%**************************************************************************
    global I;
    % calls out the user input parameters
    [del_Vrest lambda_Ach lambda_i graphFlag Nsearch branch Nspace] = ...
        deal(I.del_Vrest, I.lambda_Ach, I.lambda_i, I.graphFlag, ...
        I.Nsearch, I.branch, I.Nspace);
end

% calls out the constants
[N_ee_a N_ei_a N_ee_b N_ei_b N_ie_b N_ii_b phi_ee_sc phi_ei_sc phi_ie_sc ...
    phi_ii_sc] = deal(H.Nee_a, H.Nei_a, H.Nee_b, H.Nei_b, H.Nie_b, ...
    H.Nii_b, H.phi_ee_sc, H.phi_ei_sc, H.phi_ie_sc, H.phi_ii_sc);
 
%Call alistairs code to get steady state solution
[Qeeqm, Qieqm, Veeqm, Vieqm]=steady_states_delV_lambda(del_Vrest,...
    lambda_Ach,lambda_i,graphFlag,Nsearch);

% choose either top or bottom branch for the initial condition
switch branch
    case 0
        [Qe_eqm Qi_eqm Ve_eqm Vi_eqm] = ...
            deal(Qeeqm(1), Qieqm(1), Veeqm(1), Vieqm(1));
    case 1
        [Qe_eqm Qi_eqm Ve_eqm Vi_eqm] = ...
            deal(Qeeqm(end), Qieqm(end), Veeqm(end), Vieqm(end));
    otherwise
        warning('Unknown Branch!');
        error('Only "0" or "1" are acceptable for "Branch" input');
end

%Load-up equilibrium values
    
phi_ee_eqm = Qe_eqm;
phi_ei_eqm = Qe_eqm;
PHI_ee_eqm = N_ee_a*phi_ee_eqm + N_ee_b*Qe_eqm + phi_ee_sc;
PHI_ie_eqm = N_ie_b*Qi_eqm + phi_ie_sc;
PHI_ei_eqm = N_ei_a*phi_ei_eqm + N_ei_b*Qe_eqm + phi_ei_sc;
PHI_ii_eqm = N_ii_b*Qi_eqm + phi_ii_sc;

%Subsidiary variables
Xee_eqm = 0;
Xei_eqm = 0;
Xie_eqm = 0;
Xii_eqm = 0;
Yee_eqm = 0;
Yei_eqm = 0;
    
equilibrium = [Ve_eqm; Vi_eqm; PHI_ee_eqm; Xee_eqm; PHI_ei_eqm; Xei_eqm; ...
    PHI_ie_eqm; Xie_eqm; ; PHI_ii_eqm; Xii_eqm; phi_ee_eqm; Yee_eqm; ...
    phi_ei_eqm; Yei_eqm];

[eigenvalues_14x14, largest_eigenvalue_14x14, oscillation_freq_14x14] ...
    = Steady_States_stability_14x14(equilibrium);

if (O.stability_testing_mode == 0) && (I.dataFlag == true)
    global O;   % pass the stability data to global for saving
    O.Equilibrium = [O.Equilibrium, equilibrium];
    O.eigenvalues_14x14 = [O.eigenvalues_14x14, eigenvalues_14x14];
    O.largest_eigenvalue_14x14 = ...
        [O.largest_eigenvalue_14x14, largest_eigenvalue_14x14];
    O.oscillation_freq_14x14 = ...
        [O.oscillation_freq_14x14, oscillation_freq_14x14];
end

%**************************************************************************
% This section is for displaying the steady-states data in the command
% window (optional, DATA DISPLAY purpose)
if (O.stability_testing_mode ~= 0) || (I.stabilityFlag == false)
    Qeeqm
    Qieqm
    Veeqm
    Vieqm
    switch branch
        case 0
            fprintf('\n Bottom Branch \n\n\n');
        case 1
            fprintf('\n Upper Branch \n\n\n');
    end
    fprintf('\n 14x14 Steady States stability: \n\n');
    eigenvalues_14x14
    largest_eigenvalue_14x14
    oscillation_freq_14x14
    fprintf('\n end of 14x14 Steady States stability test \n\n');
end
%**************************************************************************
    
%Loop over all space
x=1:Nspace;
y=x;

for i = 1:length(equilibrium)
    f(x,y,i) = equilibrium(i);
end

return