function H = init_hasselmo_globs
% Initialize a structure H containing the Hasselmo modifications to the
% Wright constants.
% NB: Indexing convention is 'j2k' (not 'q_from_p' as for Wright)
% ASR: 7-Jul-2004

% membrane rate-constants (assume Liley values here: tau_e,i = 40 ms)
[H.tau_e, H.tau_i] = deal(40, 40);  %SHOULD BE 40

% sigmoid characteristics
[H.Qe_max,  H.Qi_max]  = deal(30, 60);			% sigmoid maximum (s^-1)
[H.theta_e, H.theta_i] = deal(-58.5, -58.5);	% sigmoid threshold (mV)
% [H.theta_e, H.theta_i] = deal(-60, -60);	% sigmoid threshold (mV)

% [H.sigma_e, H.sigma_i] = deal(5, 5);	% Wright default: std devn for threshold (mV)
% [H.sigma_e, H.sigma_i] = deal(6.4779, 12.9557);	% equiv Liley values (mV)
[H.sigma_e, H.sigma_i] = deal(4.0, 6.0);

% gain per synapse at resting voltage (millivolt.sec)
% [H.ge, H.gi] = deal(1.20e-3, -2.95e-3);
% [H.ge, H.gi] = deal(1.00e-3, -1.20e-3);
[H.ge, H.gi] = deal(1.00e-3, -1.05e-3);


% voltage limits
[H.Ve_rev,  H.Vi_rev]  = deal(0, -70);		% reversal potential (mV)
[H.Ve_rest, H.Vi_rest] = deal(-64, -64);	% resting potential (mV)

% connectivities: j2k convention (dimensionless)
[H.Nee_a, H.Nei_a]               		 = deal(3710, 3710);			% cortico-cortical 
[H.Nee_b, H.Nei_b, H.Nie_b, H.Nii_b] 	 = deal(410, 410, 800, 800);	% intracortical
[H.Nee_sc, H.Nei_sc, H.Nie_sc, H.Nii_sc] = deal(50, 50, 50, 50);	% subcortical

% Nee and Nie totals for cortico-cortical plus intracortical
H.Nee_ab = H.Nee_a + H.Nee_b;
H.Nei_ab = H.Nei_a + H.Nei_b;

% default subcortical fluxes
H.phi_ee_sc = 0.5 * H.Nee_sc * H.Qe_max;
H.phi_ei_sc = 0.5 * H.Nei_sc * H.Qe_max;
H.phi_ie_sc = 0.5 * H.Nie_sc * H.Qi_max;
H.phi_ii_sc = 0.5 * H.Nii_sc * H.Qi_max;

% d/dV derivatives of psi_ij weighting functions
H.d_psi_ee = -1/(H.Ve_rev - H.Ve_rest);
H.d_psi_ei = -1/(H.Ve_rev - H.Vi_rest);
H.d_psi_ie = -1/(H.Vi_rev - H.Ve_rest);
H.d_psi_ii = -1/(H.Vi_rev - H.Vi_rest);

return

%------------------------------------------------------------------------
